@@ -86,9 +86,7 @@
 #define HAVE_CRYPT 1
 #define HAVE_FLOCK 1
 #define HAVE_VSNPRINTF 1
-#define HAVE_ISNAN 1
 #define HAVE_FINITE 1
-#define HAVE_ISINF 1
 #define HAVE_HYPOT 1
 #define HAVE_ACOSH 1
 #define HAVE_ERF 1
@@ -167,6 +165,6 @@
 #define RUBY_LIB "/usr/local/lib/ruby/1.8"
 #define RUBY_SITE_LIB "/usr/local/lib/ruby/site_ruby"
 #define RUBY_SITE_LIB2 "/usr/local/lib/ruby/site_ruby/1.8"
-#define RUBY_PLATFORM "i386-openbsd4.3"
-#define RUBY_ARCHLIB "/usr/local/lib/ruby/1.8/i386-openbsd4.3"
-#define RUBY_SITE_ARCHLIB "/usr/local/lib/ruby/site_ruby/1.8/i386-openbsd4.3"
+#define RUBY_PLATFORM "i386-openbsd4.4"
+#define RUBY_ARCHLIB "/usr/local/lib/ruby/1.8/i386-openbsd4.4"
+#define RUBY_SITE_ARCHLIB "/usr/local/lib/ruby/site_ruby/1.8/i386-openbsd4.4"
